@@ -43,6 +43,7 @@ def imports() -> str:
         "from edgedb import RelativeDuration, AsyncIOClient, create_async_client",
         "from pydantic import BaseModel, Field, PrivateAttr",
         f"from {PATH_TO_MODULE} import Node, Resolver, NodeException, ResolverException, UpdateOperation, Batch, Unset, ComputedPropertyException, is_unset",
+        'EdgeResolverType = T.TypeVar("EdgeResolverType", bound=Resolver)',
     ]
     return "\n".join(lines)
 
@@ -166,13 +167,19 @@ class {CONFIG_NAME}:
     """
 
 
-def stringify_dict(d: T.Union[T.Dict[str, str], str]) -> str:
+def stringify_dict(
+    d: T.Union[T.Dict[str, str], str], stringify_value: bool = True
+) -> str:
     if type(d) is not dict:
         s = f"{d}"
         if type(d) is not bool:
-            s = f'"{s}"'
+            if stringify_value:
+                s = f'"{s}"'
         return s
-    inner = [f'"{k}":{stringify_dict(v)}' for k, v in d.items()]
+    inner = [
+        f'"{k}":{stringify_dict(v, stringify_value=stringify_value)}'
+        for k, v in d.items()
+    ]
     return f"{{{','.join(inner)}}}"
 
 
@@ -188,7 +195,9 @@ def edgedb_conversion_type_from_prop(prop: Property) -> str:
     return s
 
 
-def build_node_and_resolver(object_type: ObjectType, hydrate: bool) -> str:
+def build_node_and_resolver(
+    object_type: ObjectType, edge_resolver_map_strs: T.List[str], hydrate: bool
+) -> str:
     # need to sort props and links by required, exclusive, no default, rest
     object_type.properties.sort(
         key=lambda x: f"{not x.is_computed}-{x.required}-{x.is_exclusive}-{x.default}",
@@ -271,6 +280,7 @@ def {prop.name}(self) -> {prop.type_str}:
     updatable_links: T.Set[str] = set()
     exclusive_links: T.Set[str] = set()
     link_conversion_map: T.Dict[str, T.Dict[str, str]] = {}
+    edge_resolver_map: T.Dict[str, str] = {}
 
     for link in object_type.links:
         if link.name == "__type__":
@@ -281,6 +291,7 @@ def {prop.name}(self) -> {prop.type_str}:
             "readonly": link.readonly,
             "required": link.required,
         }
+        edge_resolver_map[link.name] = f"{link.target.model_name}Resolver"
         if not link.readonly and not link.is_computed:
             updatable_links.add(link.name)
         if link.is_exclusive:
@@ -354,6 +365,19 @@ def {prop.name}(self) -> {prop.type_str}:
     resolver_get_functions_str = build_get_functions_str(
         node_name=object_type.node_name, exclusive_field_names=exclusive_fields
     )
+
+    edge_resolver_val_strs = [
+        f"T.Type[{v}]" for v in sorted(set(edge_resolver_map.values()))
+    ]
+    union_type = (
+        f"T.Union[{', '.join(edge_resolver_val_strs)}]"
+        if edge_resolver_map
+        else "EdgeResolverType"
+    )
+    edge_resolver_map_strs.append(
+        f"{node_resolver_name}._edge_resolver_map: T.Dict[str, {union_type}] ="
+        f" {stringify_dict(edge_resolver_map, stringify_value=False)}"
+    )
     resolver_inner_strs = [
         resolver_properties_str,
         resolver_link_functions_str,
@@ -373,17 +397,21 @@ async def build_nodes_and_resolvers(
 ) -> str:
     object_types = await introspect_objects(client)
     node_strs: T.List[str] = []
+    edge_resolver_map_strs: T.List[str] = []
     for object_type in object_types:
         node_strs.append(
             build_node_and_resolver(
-                object_type, hydrate=object_type.node_name in nodes_to_hydrate
+                object_type,
+                edge_resolver_map_strs=edge_resolver_map_strs,
+                hydrate=object_type.node_name in nodes_to_hydrate,
             )
         )
     update_forward_refs_str = "\n".join(
         [f"{o.node_name}Insert.update_forward_refs()" for o in object_types]
     )
     nodes_str = "\n".join(node_strs)
-    return f"{nodes_str}\n\n{update_forward_refs_str}"
+    edge_resolver_map_str = "\n".join(edge_resolver_map_strs)
+    return f"{nodes_str}\n\n{update_forward_refs_str}\n\n{edge_resolver_map_str}"
 
 
 class DBVendor(str, Enum):
