@@ -29,10 +29,14 @@ class UpdateOperation(str, Enum):
     REMOVE = "-="
 
 
+EdgeResolverType = T.TypeVar("EdgeResolverType", bound="Resolver")
+
+
 class Resolver(BaseModel, T.Generic[NodeType]):
     """Can construct an EdgeQL query string from this!"""
 
     _node: T.ClassVar[T.Type[NodeType]]
+    _edge_resolver_map: T.ClassVar[T.Dict[str, EdgeResolverType]]
 
     _filter: str = PrivateAttr(None)
     _order_by: str = PrivateAttr(None)
